@@ -10,7 +10,7 @@ for photos, etc. - and configure them to save tthe files in different places,
 creating the directories on demand, according to a pattern defined by you.
 
 
-Copyright © 2010-2011 by Lúcuma labs (http://lucumalabs.com).  
+Copyright © 2010-2012 by Lúcuma labs (http://lucumalabs.com).  
 MIT License. (http://www.opensource.org/licenses/mit-license.php)
 
 """
@@ -28,7 +28,7 @@ from werkzeug.exceptions import RequestEntityTooLarge, UnsupportedMediaType
 
 from . import utils
 
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 
 
 IMAGES = ('.jpg', '.jpeg', '.png', '.gif', '.bmp')
@@ -326,11 +326,15 @@ class File(object):
             url = '%s/%s/%s' % (self.base_url, self.relpath, self.name)    
         self.url = url
     
+    @property
+    def __dict__(self):
+        return self.to_dict()
+
     def __nonzero__(self):
         return bool(self.path)
     
     def __repr__(self):
-        return self.to_json()
+        return repr(self.to_dict())
     
     def remove(self):
         try:
@@ -381,7 +385,9 @@ if sqlalchemy_available:
         def process_bind_param(self, value, dialect):
             if value is None:
                 return None
-            return value.to_json()
+            if hasattr(value, 'to_json'):
+                return value.to_json()
+            return utils.json.dumps(value)
         
         def process_result_value(self, value, dialect):
             if not value:
